from distutils.core import setup

setup(
    name='nester9',
    version='1.2.0',
    description='A simple printer of nested lists',
    author='will',
    author_email='example@example.com',
    url='https://example.com',
    py_modules=['nester9']
)
